#!/usr/bin/env python
import sys

def stdin(argv):
    parse_stdin = ('-' in argv)
    if parse_stdin:
        argv = [x for x in argv if x != '-']
        input_lines = sys.stdin.readlines()
        argv += [line.strip() for line in input_lines if line.strip()]
    return argv



import os

from jinja2 import Template

TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), 'templates')

def renderer(data, datatype, oneline=False):
    """
    Render data of type datatype
    Example datatype: "blacklist/lookup"
    """
    template_path = os.path.join(TEMPLATE_DIR, datatype)
    if oneline:
        template_path += '_oneline'
    with open(template_path) as temp_f:
        template_text = temp_f.read()
    template = Template(template_text)
    return template.render(data=data).encode('utf-8')



#!/usr/bin/env python
"""
RiskIQ API
"""
__author__ = 'RiskIQ Research'
__version__ = '0.1-ALPHA'
import json
from datetime import timedelta, datetime

import requests

# Acceptable string time format for all requests
TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
TIME_FORMAT_DAY = '%Y-%m-%d 00:00:00'

def today():
    """
    Generates a date string for today.

    :return: Date string of today in "yyyy-mm-dd" format, accepted by API
    """
    return datetime.strftime(datetime.now(), '%Y-%m-%d')

def format_date(dt, day=False):
    """
    Generates a date string in the required format from a datetime object.

    :param dt: Datetime object
    :param day: Bool, whether to take the floor of the day
        (1 means beginning of today since midnight)
    :return: string in acceptable date format
    """
    fmt = TIME_FORMAT
    if day:
        fmt = TIME_FORMAT_DAY
    return datetime.strftime(dt, fmt)

def date_range(days=1, start=None, end=None):
    """
    Generate a start date and an end date based off of how many days.

    :param days: How many days to include from today(for generating 30 day time windows, etc.)
    :param start: Override start date.
    :param end: Override end date
    :return: (start, end) tuple of strings in acceptable date format
    """
    if not any([days, start, end]):
        return None, None
    if start is None:
        start = format_date(datetime.now() - timedelta(days=days-1), day=True)
    elif isinstance(start, datetime):
        start = format_date(start)
    elif isinstance(start, basestring):
        start = start.replace('today', today())
    if end is None:
        end = format_date(datetime.now())
    elif isinstance(end, datetime):
        end = format_date(end)
    elif isinstance(end, basestring):
        end = end.replace('today', today())
    return start, end

class Client(object):
    """
    RiskIQ API Client

    Example:
    ::

        from riskiq.api import Client
        # Put credentials here.
        token, key = None, None
        client = Client(token, key)

        # Submit URLs to your project
        urls = ['http://evilexample.com/evil.php?shell=true', ...]
        client.submit_landing_page_bulk(urls, project_name='Example')

        # Get blacklist list from varying date ranges
        client.get_blacklist_list(days=5)
        data = client.get_blacklist_list(
            start="2014/08/01 00:00:00", end="today 00:00:00"
        )
        results = data['resources']
        all_malware = [x for x in results if x['malware']]
    """
    def __init__(self, token, key, server='ws.riskiq.net', version='v1'):
        self.api_base = 'https://%s/%s' % (server, version)
        self.auth = (token, key)
        self.headers = {
            'Accept': 'Application/JSON',
            'Content-Type': 'Application/JSON',
        }

    def _endpoint(self, endpoint, action, *urlparams, **params):
        """
        Return the URL for the action

        :param endpoint: The controller
        :param action: The action provided by the controller
        :param urlparams: Additional endpoints(for endpoints that take part of the url as option)
        :param params: Parameters to pass to url, typically query string
        :return: Full URL for the requested action
        """
        api_url = "/".join((self.api_base, endpoint, action))
        if urlparams:
            api_url += "/".join(urlparams)
        return api_url

    def _json(self, response):
        """
        JSON response from server

        :param response: Response from the server
        :throws ValueError: from requests' response.json() error
        :return: response deserialized from JSON
        """
        if response.status_code == 204:
            return None
        try:
            return response.json()
        except ValueError as e:
            raise ValueError(
                'Exception: %s\n'
                'request: %s, response code: %s, response: %s' % (
                    str(e), response.request.url, response.status_code,
                    response.content,
                )
            )

    def _get(self, endpoint, action, *urlparams, **params):
        """
        Request API Endpoint - for GET methods.

        :param endpoint: Endpoint
        :param action: Endpoint Action
        :param urlparams: Additional endpoints(for endpoints that take part of the url as option)
        :param params: Parameters to pass to url, typically query string
        :return: response deserialized from JSON
        """
        api_url = self._endpoint(endpoint, action, *urlparams, **params)
        response = requests.get(api_url, auth=self.auth, headers=self.headers,
            verify=True, params=params)
        return self._json(response)

    def _post(self, endpoint, action, data, *urlparams, **params):
        """
        Submit to API Endpoint - for POST methods.

        :param endpoint: Endpoint
        :param action: Endpoint Action
        :param urlparams: Additional endpoints(for endpoints that take part of the url as option)
        :param params: Parameters to pass to url, typically query string
        :return: response deserialized from JSON
        """
        api_url = self._endpoint(endpoint, action, *urlparams, **params)
        data = json.dumps(data)
        response = requests.post(api_url, auth=self.auth, headers=self.headers, verify=True, data=data, params=params)
        return self._json(response)

    def get_affiliate_campaign_summary(self, days=1, start=None, end=None):
        """
        Return the affiliate campaign summary report for the given date range.

        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: data containing the number of results and the objects
        """
        start, end = date_range(days, start, end)
        return self._get('affiliate', 'campaignSummary', 
            startDateInclusive=start, endDateExclusive=end)

    def get_affiliate_incident_list(self, known_profile=None, 
        max_results=None, days=1, start=None, end=None):
        """
        Return the affiliate campaign summary report for the given date range.

        :param known_profile: Bool, only return incidents that match a known profile
        :param max_results: maximum number of results to return
        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: data containing the number of results and the objects
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        if known_profile is not None:
            kwargs['knownProfile'] = known_profile
        if max_results is not None:
            kwargs['maxResults'] = max_results
        return self._get('affiliate/incident', 'list', **kwargs)

    def get_binary_list(self, virus_total_only=None,
            client_workspace_only=None, days=1, start=None, end=None):
        """
        Return a list of all binaries in date range

        :param virus_total_only: Bool, only include those flagged by VT
        :param client_workspace_only: Bool, only include those found in crawls
        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: data containing the number of results and the objects
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        if virus_total_only is not None:
            kwargs['virus_total_only'] = virus_total_only
        if client_workspace_only is not None:
            kwargs['client_workspace_only'] = client_workspace_only
        return self._get('binary', 'list', **kwargs)

    def get_binary_data(self, md5_hash):
        """
        Query for the binary encoded base64 with the given md5 hash

        :param md5_hash: md5 hash of the binary data
        :return: object containing a dict with 'data' key encoded in base64
        """
        return self._get('binary', 'data', md5=md5_hash)

    def get_blacklist_lookup(self, url):
        """
        Query blacklist on url.

        :param url: URL to query blacklist on.
        :return: Blacklist Dict
        """
        result = self._get('blacklist', 'lookup', url=url)
        if result and 'description' not in result:
            result['description'] = ''
        return result

    def get_blacklist_incident(self, url):
        """
        Query blacklist incidents by url.

        :param url: URL to query blacklist on.
        :return: Blacklist incident
        """
        return self._get('blacklist', 'incident', url=url)

    def get_blacklist_incident_list(self, all_workspace_crawls=None, 
        days=1, start=None, end=None):
        """
        Query blacklist incidents

        :param url: list of blacklist incidents within timeframe
        :param all_workspace_crawls:False by default, filtered to crawls that
            are either landing pages, site scanning, or matching a brand
            classifier
        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: Blacklist list
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        if all_workspace_crawls is not None:
            kwargs['all_workspace_crawls'] = all_workspace_crawls
        return self._get('blacklist/incident', 'list', **kwargs)

    def get_blacklist_list(self, blacklist_filter=None, 
        days=1, start=None, end=None):
        """
        Query blacklisted resources

        :param blacklist_filter: None, or one of
            'blackhole', 'sakura', 'exploitKit'
        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: all blacklisted resources
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        if blacklist_filter is not None:
            kwargs['filter'] = blacklist_filter
        return self._get('blacklist', 'list', **kwargs)

    def get_blacklist_malware(self, blacklist_filter=None, confidence=None,
        days=1, start=None, end=None):
        """
        Query for all discovered malware resources generated within a
        particular period.

        :param blacklist_filter: None, or one of
            'blackhole', 'sakura', 'exploitKit'
        :param confidence: to restrict the result set by malicious probability
            'H', 'M', 'L' (high, medium, low)
        :param days: How many days to include from today(for generating 30 day
            time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: all blacklisted resources
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        if blacklist_filter is not None:
            kwargs['filter'] = blacklist_filter
        if confidence is not None:
            kwargs['confidence'] = confidence
        return self._get('blacklist', 'malware', **kwargs)

    def __get_blacklist_exploit_binary(self, days=1, start=None, end=None):
        """
        Query for all PE format binaries on webpages used for exploitation

        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: all binaries
        """
        raise NotImplementedError('Not implemented server-side')
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateExclusive': end,
        }
        return self._get('blacklist', 'exploitBinary', **kwargs)

    def get_crawl_volume_daily_summary(self, days=1, start=None, end=None):
        """
        Query for the crawl volume daily summary report for the date range

        :param days: How many days to include from today(for generating 30 day time windows, etc.)
        :param start: Override start date.
        :param end: Override end date
        :return: crawl volume daily summary
        """
        start, end = date_range(days, start, end)
        kwargs = {
            'startDateInclusive': start,
            'endDateInclusive': end,
        }
        return self._get('crawlVolume', 'dailySummary', **kwargs)

    def get_dns_data_by_name(self, name, rrtype=None, maxresults=1000):
        """
        Get the passive dns results by hostname.

        :param name: hostname to query. Can also use wildcards, e.g. *.test.com
        :param rrtype: Record Type to limit searches to
        :param maxresults: Max Results to Return(default 1,000)
        :return: return a JSON object of the data
        """
        return self._get('dns', 'name', name=name, rrType=rrtype,
            maxResults=maxresults)

    def get_dns_data_by_ip(self, ip, rrtype=None, maxresults=1000):
        """
        Get the passive dns results by ip address, query data

        :param ip: IP address of query, can also include wildcard, e.g. 192.168.0.*
        :param rrtype: Record Type to limit searches to
        :param maxresults: Max Results to Return(default 1,000)
        :return: return a JSON object of the data
        """
        return self._get('dns', 'data', ip=ip, rrType=rrtype,
            maxResults=maxresults)

    def get_dns_ptr_by_ip(self, ip, rrtype=None, maxresults=1000):
        """
        Get the reverse dns of a particular IP.

        :param ip: IP Address to Query.
        :param rrtype: Record Type to limit searches to
        :param maxresults: Max Results to Return(default 1,000)
        :return: return a JSON object of the data
        """
        return self._get('dns', 'name', ip=ip, rrType=rrtype,
            maxResults=maxresults)

    def get_dns_data_by_data(self, hostname, rrtype=None, maxresults=1000):
        """
        Get the passive dns results by ip address, query data

        :param ip: IP address of query, can also include wildcard, e.g. 192.168.0.*
        :param rrtype: Record Type to limit searches to
        :param maxresults: Max Results to Return(default 1,000)
        :return: return a JSON object of the data
        """
        return self._get('dns', 'data', name=hostname, rrType=rrtype, 
            maxResults=maxresults)

    def get_landing_page(self, md5_hash, whois=None):
        """
        Retrieve a single landing page by MD5.

        :param md5_hash: md5 of the landing page
        :param whois: Bool, whether to include whois information
        :return: landing page data
        """
        kwargs = {}
        if whois is not None:
            kwargs['whois'] = whois
        return self._get('landingPage', md5_hash, **kwargs)

    def submit_landing_page(self, url, project_name=None):
        """
        Submit a single landing page.

        :param url: Url to submit.
        :param project_name: Project name to submit landing page to
        :return: returns json of landing page.
        """
        data = {'url': url}
        if project_name:
            data['projectName'] = project_name
        return self._post('landingPage', '', data)

    def get_landing_page_crawled(self, whois=None,
        days=None, start=None, end=None):
        """
        List landing pages by crawl date - maximum of 100

        :param whois: Bool, whether to include whois information
        :param days: How many days you want to grab
        :param start: Which date to start from, use time_format.
        :param end: Date to end, use time_format.
        :return: landing page data
        """
        start, end = date_range(days, start, end)
        if any([days, start, end]):
            kwargs = { 'start': start, 'end': end }
        else:
            kwargs = {}
        if whois is not None:
            kwargs['whois'] = whois
        return self._get('landingPage', 'crawled', **kwargs)

    def get_landing_page_flagged(self, whois=None,
        days=None, start=None, end=None):
        """
        List landing pages by known profile creation date - maximum of 100

        :param whois: Bool, whether to include whois information
        :param days: How many days you want to grab
        :param start: Which date to start from, use time_format.
        :param end: Date to end, use time_format.
        :return: landing page data
        """
        start, end = date_range(days, start, end)
        if any([days, start, end]):
            kwargs = { 'start': start, 'end': end }
        else:
            kwargs = {}
        if whois is not None:
            kwargs['whois'] = whois
        return self._get('landingPage', 'flagged', **kwargs)

    def submit_landing_page_bulk(self, urls, project_name=None):
        """
        Submit landing pages in bulk

        :param urls: Urls to submit.
        :param project_name: Project name to submit landing page to
        :return: returns json of landing page.
        """
        if project_name is not None:
            data = {
                'entry': [
                    {
                        'url': url, 
                        'projectName': project_name
                    }
                    for url in urls
                ]
            }
        else:
            data = {'entry': [{'url': url} for url in urls]}
        return self._post('landingPage', 'bulk', data)

    def get_landing_page_malicious_binary(self, whois=None,
        days=1, start=None, end=None):
        """
        List landing pages with malicious binary incidents.

        :param whois: Bool, whether to include whois information
        :param days: How many days you want to grab
        :param start: Which date to start from, use time_format.
        :param end: Date to end, use time_format.
        :return: landing page data
        """
        start, end = date_range(days, start, end)
        kwargs = { 'start': start, 'end': end }
        if whois is not None:
            kwargs['whois'] = whois
        return self._get('landingPage', 'maliciousBinary', **kwargs)

    def get_landing_page_projects(self):
        """
        List all projects that landing pages may be submitted to.

        :return: all projects
        """
        return self._get('landingPage', 'projects')

    def get_android(self, package_name):
        """
        Retrieve an android application by package name.
        If the app is not found, 404 NOT FOUND is returned.

        :param package_name: name of android package
        :return: the requested app
        """
        return self._get('mobile/android', package_name)

    def get_android_lookup(self, url):
        """
        Retrieve an android app by store URL.
        The store URL should be of the form
        https://play.google.com/store/apps/details?id=[package name]

        :param url: The store URL
        :return: app details
        """
        return self._get('mobile/android', 'lookup', url=url)

    def get_mobile_incident(self, incident_id):
        """
        Retrieve an mobile app incident by ID.
        If the incident is not found, 404 NOT FOUND is returned.

        :param incident_id: Long int ID
        :return: mobile incident
        """
        return self._get('mobile/incident', '%d' % incident_id)

    def get_mobile_incident_list(self, days=1, start=None, end=None):
        """
        List app incidents by their incident creation date.

        :param days: How many days you want to grab
        :param start: Which date to start from, use time_format.
        :param end: Date to end, use time_format.
        :return: mobile incidents
        """
        start, end = date_range(days, start, end)
        return self._get('mobile/incident', 'list', 
            startDateInclusive=start, endDateExclusive=end)

    def get_page(self, crawl_guid, page_guid):
        """
        retrieve a page and return it

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :return: requested page
        """
        return self._get('page', '%s/%s' % (crawl_guid, page_guid))

    def get_page_dom(self, crawl_guid, page_guid):
        """
        retrieve a page and return its DOM

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :return: requested page
        """
        return self._get('page', '%s/%s/dom' % (crawl_guid, page_guid))

    def get_page_response(self, crawl_guid, page_guid):
        """
        retrieve a page and return it

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :return: requested page
        """
        return self._get('page', '%s/%s/response' % (crawl_guid, page_guid))

    def get_page_child_dom(self, crawl_guid, page_guid, child_guid):
        """
        retrieve a page and return its DOM

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :param child_guid: child GUID
        :return: requested page
        """
        return self._get('page', '%s/%s/%s/dom' % 
            (crawl_guid, page_guid, child_guid)
        )

    def get_page_child_dom_text(self, crawl_guid, page_guid, child_guid):
        """
        retrieve a page and return its DOM text

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :param child_guid: child GUID
        :return: requested page
        """
        return self._get('page', '%s/%s/%s/domText' % 
            (crawl_guid, page_guid, child_guid)
        )

    def get_page_child_response(self, crawl_guid, page_guid, child_guid):
        """
        retrieve a page and return its response

        :param crawl_guid: crawl GUID
        :param page_guid: page GUID
        :param child_guid: child GUID
        :return: requested page
        """
        return self._get('page', '%s/%s/%s/response' % 
            (crawl_guid, page_guid, child_guid)
        )

    def get_project_list(self):
        """
        List all projects.
        """
        return self._get('project', 'list')

    def get_project_keywords(self, project_id):
        """
        List all keywords associated to specified project.

        :param project_id: Integer ID of the project
        :return: Keywords of project
        """
        return self._get('project', '%d/keywords' % project_id)

    def get_proxy_ip(self, ip):
        """
        Lookup a proxy by IP

        :param ip: ip address of proxy
        :return: proxy
        """
        return self._get('proxy', 'ip/%s' % ip)

    def get_zlist_urls(self, days=1, start=None, end=None):
        """
        Get the current zlist urls.

        :param days: How many days you want to grab
        :param start: Which date to start from, use time_format.
        :param end: Date to end, use time_format.
        :return: all URLs
        """
        start, end = date_range(days, start, end)
        return self._get('zlist', 'urls', start=start, end=end)



#!/usr/bin/env python
__author__ = 'jpleger'
import os
import sys
import json
CONFIG_PATH = os.path.expanduser('~/.config/riskiq')
CONFIG_FILE = os.path.join(CONFIG_PATH, 'api_config.json')
CONFIG_DEFAULTS = {
    'api_server': 'ws.riskiq.net',
    'api_version': 'v1',
    'api_token': '',
    'api_private_key': '',
}


class Config(object):
    def __init__(self, **kwargs):
        self.config = CONFIG_DEFAULTS
        try:
            self.load_config(**kwargs)
        except ValueError as e:
            print >> sys.stderr, "ERROR:", e.message
            sys.exit(1)

    def write_config(self):
        json.dump(self.config, open(CONFIG_FILE, 'w'), indent=4, separators=(',', ': '))
        return True

    def load_config(self, **kwargs):
        virgin_config = False
        if not os.path.exists(CONFIG_PATH):
            virgin_config = True
            os.makedirs(CONFIG_PATH)
        if not os.path.exists(CONFIG_FILE):
            virgin_config = True
        if not virgin_config:
            self.config = dict(json.load(open(CONFIG_FILE)))
        if kwargs:
            self.config.update(kwargs)
        if virgin_config or kwargs:
            self.write_config()
        if 'api_token' not in self.config or not 'api_private_key' in self.config:
            raise ValueError("API token or private key missing. Run 'riq-config' to configure.")
        return True

    @property
    def options(self):
        return self.config.keys()

    def get(self, item, default=None):
        if item in self.config:
            return self.config[item]
        else:
            return default



import sys
import os
import json
from argparse import ArgumentParser

from riskiq.api import Client
from riskiq.config import Config
from riskiq.cli import util


def bin_list(client, as_json=False, **kwargs):
    ''' List suspicious binaries within a specific date range '''
    data = client.get_binary_list(**kwargs)
    if as_json:
        print(json.dumps(data, indent=4))
    else:
        for binary in data['binaryIncident']:
            print(binary['md5'])


def bin_download(client, md5hash, as_json=False, output=None, output_dir=None):
    ''' Download a suspicious binary from its md5 hash '''
    data = client.get_binary_data(md5hash)
    if as_json:
        print(json.dumps(data, indent=4))
    if output is not None:
        with open(output, 'w') as f:
            f.write(data['data'].decode('base64'))
    elif output_dir is not None:
        path = os.path.join(output_dir, md5hash + '.bin')
        with open(path, 'w') as f:
            f.write(data['data'].decode('base64'))
    else:
        print(data['data'].decode('base64'))

def main():
    parser = ArgumentParser()
    subs = parser.add_subparsers(dest='cmd')

    list_parser = subs.add_parser('list', help='list binaries in date range')
    list_parser.add_argument('--days', '-d', default=1, type=int,
        help='days to query')
    list_parser.add_argument('--start', '-s', default=None,
        help='start datetime in yyyy-mm-dd HH:MM:SS format')
    list_parser.add_argument('--end', '-e', default=None,
        help='end datetime in yyyy-mm-dd HH:MM:SS format')
    list_parser.add_argument('-j', '--json', action="store_true",
        dest='as_json', help="Output as JSON")

    download_parser = subs.add_parser('download',
        help='download from md5 hash, or hashes')
    download_parser.add_argument('md5hash', nargs='+')
    download_parser.add_argument('-j', '--json', action="store_true",
        dest='as_json', help="Output as JSON")
    download_parser.add_argument('-o', '--output',
        help='path to output file to')
    download_parser.add_argument('-d', '--output-dir',
        help='dir to dump $hash.bin to')

    args = parser.parse_args()
    kwargs = {'as_json': args.as_json}
    if hasattr(args, 'days'):
        kwargs['days'] = args.days
        kwargs['start'] = args.start
        kwargs['end'] = args.end

    config = Config()
    client = Client(token=config.get('api_token'), key=config.get('api_private_key'),
                    server=config.get('api_server'), version=config.get('api_version'))
    
    if args.cmd == 'list':
        bin_list(client, **kwargs)
    elif args.cmd == 'download':
        hashes = util.stdin(args.md5hash)
        for i, md5hash in enumerate(hashes):
            output = args.output
            if output and len(hashes) > 1:
                output = '%s.%d' % (args.output, i)
            bin_download(client, md5hash,
                output=output, output_dir=args.output_dir,
                **kwargs)

if __name__ == '__main__':
    main()



import sys
import json
from argparse import ArgumentParser

from riskiq.api import Client
from riskiq.config import Config
from riskiq.render import renderer
from riskiq.cli import util

FILTERS = ('blackhole', 'sakura', 'exploitKit')
CONFIDENCES = ('H', 'M', 'L')

def bl_lookup(client, url, oneline=False, as_json=False):
    data = client.get_blacklist_lookup(url)
    if as_json:
        print(json.dumps(data, indent=4))
    elif data:
        print(renderer(data, 'blacklist/lookup', oneline=oneline))

def bl_incident(client, url, oneline=False, as_json=False):
    data = client.get_blacklist_incident(url)
    if as_json:
        print(json.dumps(data, indent=4))
    elif data:
        print(renderer(data, 'blacklist/incident', oneline=oneline))

def bl_incidentlist(client, oneline=False, as_json=False,
    **kwargs):
    data = client.get_blacklist_incident_list(**kwargs)
    if as_json:
        print(json.dumps(data, indent=4))
    elif data:
        print(renderer(data, 'blacklist/incident', oneline=oneline))

def bl_list(client, bl_filter=None, oneline=False, as_json=False,
    **kwargs):
    if bl_filter not in (None, ) + FILTERS:
        raise ValueError('Invalid filter. Must be one of %s' % str(FILTERS))
    data = client.get_blacklist_list(blacklist_filter=bl_filter, **kwargs)
    if as_json:
        print(json.dumps(data, indent=4))
    elif data:
        print(renderer(data, 'blacklist/malware', oneline=oneline))

def bl_malware(client, oneline=False, as_json=False,
    bl_filter=None, confidence=None, **kwargs):
    if bl_filter not in (None, ) + FILTERS:
        raise ValueError('Invalid filter.\nMust be one of %s' % str(FILTERS))
    if confidence not in (None, ) + CONFIDENCES:
        raise ValueError('Invalid confidence.\n'
            'Must be one of %s' % str(CONFIDENCES))
    data = client.get_blacklist_malware(blacklist_filter=bl_filter,
        confidence=confidence, **kwargs)
    if as_json:
        print(json.dumps(data, indent=4))
    elif data:
        print(renderer(data, 'blacklist/malware', oneline=oneline))

def main():
    parser = ArgumentParser()
    subs = parser.add_subparsers(dest='cmd')

    lookup_parser = subs.add_parser('lookup', help='Query blacklist on URL')
    lookup_parser.add_argument('urls', nargs='+')
    lookup_parser.add_argument('-l', '--oneline', action="store_true",
        help="Output one line per entry")
    #lookup_parser.add_argument('-s', '--short', action="store_true",
        #help="Output in short format (print matching input indicator only)")
    lookup_parser.add_argument('-j', '--json', action="store_true", dest='as_json',
        help="Output as JSON")

    incident_parser = subs.add_parser('incident', help='Query blacklist incident '
        'on URL')
    incident_parser.add_argument('urls', nargs='+')
    incident_parser.add_argument('-l', '--oneline', action="store_true",
        help="Output one line per entry")
    #incident_parser.add_argument('-s', '--short', action="store_true",
        #help="Output in short format (print matching input indicator only)")
    incident_parser.add_argument('-j', '--json', action="store_true", dest='as_json',
        help="Output as JSON")

    incident_list_parser = subs.add_parser('incidentlist',
        help='query blacklist incidents within timeframe')
    incident_list_parser.add_argument('--all-workspace-crawls', '-a',
        action='store_true', help='Filter crawls to those on workspace')
    incident_list_parser.add_argument('--days', '-d', default=1, type=int,
        help='days to query')
    incident_list_parser.add_argument('--start', '-s', default=None,
        help='start datetime in yyyy-mm-dd HH:MM:SS format')
    incident_list_parser.add_argument('--end', '-e', default=None,
        help='end datetime in yyyy-mm-dd HH:MM:SS format')
    incident_list_parser.add_argument('-l', '--oneline', action="store_true",
        help="Output one line per entry")
    #incident_list_parser.add_argument('-s', '--short', action="store_true",
        #help="Output in short format (print matching input indicator only)")
    incident_list_parser.add_argument('-j', '--json', action="store_true",
        dest='as_json', help="Output as JSON")

    list_parser = subs.add_parser('list', help = 'query blacklisted resources')
    list_parser.add_argument('--filter', '-f', default=None,
        help='Filter to one of "blackhole", "sakura" or "exploitKit"')
    list_parser.add_argument('--days', '-d', default=1, type=int,
        help='days to query')
    list_parser.add_argument('--start', '-s', default=None,
        help='start datetime in yyyy-mm-dd HH:MM:SS format')
    list_parser.add_argument('--end', '-e', default=None,
        help='end datetime in yyyy-mm-dd HH:MM:SS format')
    list_parser.add_argument('-l', '--oneline', action="store_true",
        help="Output one line per entry")
    #list_parser.add_argument('-s', '--short', action="store_true",
        #help="Output in short format (print matching input indicator only)")
    list_parser.add_argument('-j', '--json', action="store_true",
        dest='as_json', help="Output as JSON")

    malware_parser = subs.add_parser('malware',
        help='Query for all discovered malware resources generated within a '
            'particular period.')
    malware_parser.add_argument('--filter', '-f', default=None,
        help='Filter to one of "blackhole", "sakura" or "exploitKit"')
    malware_parser.add_argument('--confidence', '-c', default=None,
        help='Restrict results to malicious probability of H, M, or L\n'
            '(high, medium or low)')
    malware_parser.add_argument('--days', '-d', default=1, type=int,
        help='days to query')
    malware_parser.add_argument('--start', '-s', default=None,
        help='start datetime in yyyy-mm-dd HH:MM:SS format, or "today HH:MM:SS"')
    malware_parser.add_argument('--end', '-e', default=None,
        help='end datetime in yyyy-mm-dd HH:MM:SS format, or "today HH:MM:SS"')
    malware_parser.add_argument('-l', '--oneline', action="store_true",
        help="Output one line per entry")
    #malware_parser.add_argument('-s', '--short', action="store_true",
        #help="Output in short format (print matching input indicator only)")
    malware_parser.add_argument('-j', '--json', action="store_true",
        dest='as_json', help="Output as JSON")

    args = parser.parse_args()
    config = Config()
    client = Client(token=config.get('api_token'), key=config.get('api_private_key'),
                    server=config.get('api_server'), version=config.get('api_version'))

    kwargs = {'as_json': args.as_json, 'oneline': args.oneline}
    if hasattr(args, 'days'):
        kwargs['days'] = args.days
        kwargs['start'] = args.start
        kwargs['end'] = args.end
    if args.cmd == 'lookup':
        urls = util.stdin(args.urls)
        for url in urls:
            bl_lookup(client, url, **kwargs)
    elif args.cmd == 'incidentlist':
        bl_incidentlist(client, all_workspace_crawls=args.all_workspace_crawls,
            **kwargs)
    elif args.cmd == 'incident':
        urls = util.stdin(args.urls)
        for url in urls:
            bl_incident(client, url, **kwargs)
    elif args.cmd == 'list':
        try:
            bl_list(client, bl_filter=args.filter, **kwargs)
        except ValueError as e:
            parser.print_usage()
            print(str(e))
            sys.exit(1)
    elif args.cmd == 'malware':
        try:
            bl_malware(client, bl_filter=args.filter,
                confidence=args.confidence, **kwargs)
        except ValueError as e:
            parser.print_usage()
            print(str(e))
            sys.exit(1)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
from riskiq.api import Client
from riskiq.config import Config
from riskiq.output import PassiveDNS
from optparse import OptionParser
import re
import sys
IP_REGEX = re.compile(r'^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.([0-9]{1,3}|\*|[0-9]{1,3}/[0-9]{1,2})$')


def main():
    parser = OptionParser()
    parser.add_option('-q', '--query', dest='query', action="store_true", default=False, help="Query Domain Name")
    parser.add_option('-d', '--data', dest='rdata', action="store_true", default=False, help="Response Data")
    parser.add_option('-i', '--ip', dest='rdata_ip', action="store_true", default=False, help="Response Data(IP)")
    parser.add_option('-t', '--rrtype', dest='rrtype', default=None, help="Record Type")
    parser.add_option('-j', '--json', dest='json', action="store_true", default=False, help="Output as JSON")
    options, args = parser.parse_args()
    if not args:
        parser.print_help()
        sys.exit(-1)
    config = Config()
    client = Client(token=config.get('api_token'), key=config.get('api_private_key'),
                    server=config.get('api_server'), version=config.get('api_version'))
    qtype = None
    if options.query:
        qtype = 'query'
    if options.rdata:
        qtype = 'data'
    if options.rdata_ip:
        qtype = 'ip'
    results = []
    for arg in args:
        if not qtype:
            if IP_REGEX.match(arg):
                qtype = 'ip'
            else:
                qtype = 'query'
        if qtype == 'data':
            results.append(client.get_dns_data_by_data(arg, rrtype=options.rrtype))
        if qtype == 'ip':
            results.append(client.get_dns_data_by_ip(arg, rrtype=options.rrtype))
        if qtype == 'query':
            results.append(client.get_dns_data_by_name(arg, rrtype=options.rrtype))
    results = PassiveDNS(results)
    if options.json:
        print results.json
        sys.exit(0)
    print results.text
    sys.exit(0)




#!/usr/bin/env python

import sys
import re
import json

from riskiq.api import Client
from riskiq.config import Config
from riskiq.render import renderer
from riskiq.cli import util

IP_REGEX = re.compile(r'^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.([0-9]{1,3}|\*|[0-9]{1,3}/[0-9]{1,2})$')

def ip_hostname(addr):
    match = IP_REGEX.match(addr)
    if match:
        ip = addr
        hostname = None
    else:
        ip = None
        hostname = addr
    return ip, hostname

def get_data(client, cmd, rrtype=None, hostname=None, ip=None):
    data = None
    if cmd == 'name':
        if ip is not None:
            data = client.get_dns_ptr_by_ip(ip, rrtype=rrtype)
        elif hostname is not None:
            data = client.get_dns_data_by_name(hostname, rrtype=rrtype)
        else:
            raise ValueError('No IP or hostname')
    elif cmd == 'data':
        if ip is not None:
            data = client.get_dns_data_by_ip(ip, rrtype=rrtype)
        elif hostname is not None:
            data = client.get_dns_data_by_data(hostname, rrtype=rrtype)
        else:
            raise ValueError('No IP or hostname')
    else:
        raise ValueError('Invalid command')
    return data

def main():
    import argparse
    parser = argparse.ArgumentParser()
    subs = parser.add_subparsers(dest='cmd')

    name_p = subs.add_parser('name')
    name_p.add_argument('addrs', nargs='+', help='Hostname or IP addresses')
    name_p.add_argument('--json', '-j', action="store_true",
        help="Output as JSON")
    name_p.add_argument('--rrtype', '-t', default=None)

    data_p = subs.add_parser('data')
    data_p.add_argument('addrs', nargs='+', help='Hostname or IP addresses')
    data_p.add_argument('--json', '-j', action="store_true",
        help="Output as JSON")
    data_p.add_argument('--rrtype', '-t', default=None)

    args = parser.parse_args()

    addrs = util.stdin(args.addrs)
    for addr in addrs:
        ip, hostname = ip_hostname(addr)

        config = Config()
        client = Client(
            token=config.get('api_token'), key=config.get('api_private_key'),
            server=config.get('api_server'), version=config.get('api_version'),
        )
        try:
            data = get_data(client, args.cmd, rrtype=args.rrtype,
                hostname=hostname, ip=ip)
        except ValueError as e:
            parser.print_usage()
            print sys.stderr, str(e)
            sys.exit(1)

        if args.json:
            print(json.dumps(data, indent=4))
        elif data:
            print(renderer(data, 'dns/dns'))



#!/usr/bin/env python
import os
from ez_setup import use_setuptools
use_setuptools()

from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = 'riskiq',
    version = '0.2.5',
    description = 'client for RiskIQ REST API',
    url = "https://github.com/riskiq/python_api",
    keywords = 'riskiq API REST',
    author = "Research Team, RiskIQ",
    author_email = "research@riskiq.net",
    license = "GPLv2",
    packages = find_packages(),
    install_requires = ['requests', 'jinja2'],
    long_description=read('README.rst'),
    classifiers=[
        'Development Status :: 3 - Alpha',
        #'Development Status :: 4 - Beta',
        #'Development Status :: 5 - Production/Stable',
        #'Development Status :: 6 - Mature',
    ],
    entry_points = {
        'console_scripts': [
            'riq-dns = riskiq.cli.dns:main',
            'riq-config = riskiq.cli.config:main',
            'riq-blacklist = riskiq.cli.blacklist:main',
            'riq-zlist = riskiq.cli.zlist:main',
            'riq-landingpage = riskiq.cli.landingpage:main',
            'riq-binary = riskiq.cli.binary:main',
            #'riq-mobile = riskiq.cli.mobile:main',
        ],
    },
    package_data = {
        'riskiq': [
            'templates/blacklist/*',
            'templates/dns/*',
            'templates/zlist/*',
            'templates/landingpage/*',
        ],
    },
    include_package_data = True,
    zip_safe=False,
)



from riskiq.config import Config
from riskiq.output import GenericOutput
from optparse import OptionParser
import sys


def main():
    usage = """%prog -t TOKEN -k KEY\n       %prog -p"""
    parser = OptionParser(usage)
    parser.add_option('-t', '--token', dest='token', default='', help='API token')
    parser.add_option('-k', '--key', dest='key', default='', help='API private key')
    parser.add_option('-p', '--print', action='store_true', dest='show_config',
                      default=False, help='Show current API configuration')
    options, args = parser.parse_args()
    if options.show_config:
        config = Config()
        show_config(config)
        sys.exit(0)
    config_options = {}
    if not options.token or not options.key:
        parser.error("provide API token and secret key to configure client")
    config_options['api_token'] = options.token
    config_options['api_private_key'] = options.key

    config = Config(**config_options)
    show_config(config)
    sys.exit(0)


def show_config(config):
    print "\nCurrent Configuration:\n"
    for k, v in sorted(config.config.items()):
        print "%15s: %s" % (k, v)

if __name__ == '__main__':
    main()

